import { Children } from 'react'
import Document, { Html, Head, Main, NextScript } from 'next/document'
import Script from 'next/script'
import { ServerStyleSheets } from '@material-ui/core/styles'

// Override Document to set "lang" attribute and pre-render material UI.
// See https://github.com/mui-org/material-ui/tree/master/examples/nextjs
class MyDocument extends Document {
  render() {
    return (
      <Html lang="en">
        <Head />
        <Script src="https://platform.twitter.com/widgets.js"></Script>
        <body>
        <Main />
        <NextScript />
        </body>
      </Html>
    )
  }
}

MyDocument.getInitialProps = async (ctx) => {
  // Render app and page and get the context of the page with collected side effects.
  const sheets = new ServerStyleSheets();
  const originalRenderPage = ctx.renderPage;

  ctx.renderPage = () =>
    originalRenderPage({
      enhanceApp: (App) => (props) => sheets.collect(<App {...props} />),
    });

  const initialProps = await Document.getInitialProps(ctx);

  return {
    ...initialProps,
    // Styles fragment is rendered after the app and page rendering finish.
    styles: [...Children.toArray(initialProps.styles), sheets.getStyleElement()],
  };
};

export default MyDocument
